##  Overview
Automatically update lifecycle phases according to your organization’s policies. For example, you can set a minimum timeframe for each phase to 90 days.
The automation is triggered by any changes to the Lifecycle field on applications. The script automatically updates lifecycle phases every 90 days, based on the organization’s policies.
